%MAIN LOOPER
%This code gives for results all the physical parameters of a Loop Heat Pipe.

clc
clear all
close all

figure

tic 
format long

global m_cc cp_cc Qext Qleak mdot cp_l m_vo cp_v R_pwvo R_vowall m_pw cp_pw R_wallpw Rpw2 ...
			 m_wall cp_wall T1 T_cc Tsat hLV T_hs T_c Rt_cond mcond hLV_cond x0 T_c0

%BOUNDARY CONDITION & ASSUMPTIONS
%to calculate initial fluid properties, first initial values of temperature and pressure are needed
T_amb = 25+273.15;       %K
Pi = 10^5*(0.00000001427245898185*T_amb^4 - 0.00001713237691886840*T_amb^3 + 0.00778985619620290000*T_amb^2 - 1.58733653961135000000*T_amb + 122.10792804363100000000);             %Pa
Qext = 1000;             %W
Qleak = Qext*0.1;        %W
h_step = 1;              %s
tmax = 2500;             %s
g = 9.81;							   %m/s2
hce_ll = 8;              %W/m2*K -- isolating the liquid line
fr = 0.6;                

%Boundary conditions to the condenser (heat sink temperature and HTC)
T_hs = T_amb-4;     %K
hc = 100;           %W/m2*K

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%COSTANT FLUID PARAMETER - WATER
M_mol = 18e-3;                  %kg/mol
R = 8.314/M_mol;                %J/mol*K 
P_crit = 22.06*100000;          %Pa
k_g = 1.33;

%CONCENTRATED LOSSES COSTANT
k_90 = 0.19;
k_in1 = 0.3;
k_in2 = 0.6;
k_in3 = 0.9;
k_ou1 = 0.4;
k_ou2 = 0.5;
k_ou3 = 0.6;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%    GEOMETRY   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%CONDENSER
ri_cond = 0.007;                %m
re_cond = 0.008;                %m
L_cond = 6.6;                   %m

%LIQUID LINE
ri_ll = 0.004;                  %m
re_ll = 0.005;                  %m
z_u = 0;                        %m 
L_ll = 3;                       %m
nb_ll= 3;
Lx_ll = L_ll/(2*nb_ll);         %m
deltaz_ll = z_u/(2*nb_ll);

%VAPOUR LINE
ri_vl = 0.007;                  %m
re_vl = 0.008;                  %m
L_vl= L_ll;                     %m
nb_vl = 2;
Lx_vl= L_vl/(2*nb_vl);          %m 
deltaz_vl = z_u/(2*nb_vl);		  %m


%EVAPORATOR
%Primary Wick
rpw = 0.0095;                   %m
Lpw = 0.21;                     %m
%Vapour Grooves
rvg = 0.001;                    %m
nvg = 20;
Lvg = Lpw/2;										%m
thickev = 0.0085;               %m
%Bayoney
rbi = 0.0025;                   %m
rbe = 0.0035;                   %m
Lbay = Lpw*0.2;                 %m 
%Secondary Wick
rsw = 0.00775;                  %m
Lsw = Lpw/2;                    %m

r_vc = rpw;                     %m

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%MATERIAL FOR THE DESIRED GEOMETRY

%CONDENSER - copper
kn_cond = 401;             %W/mK
rho_mcond = 8940;          %kg/m3
cp_cond = 390;             %W/mk

%VAPOUR LINE -- copper
rho_mvl = 8940;            %kg/m3

%LIQUID LINE -- copper
rho_mll = 8940;

%PRIMARY WICK -- PE
alpha1 = 0.5;
kmpw = 0.4186;             %W/m*K
r_por_pw = 2e-5;           %m
rho_pw = 930;              %kg/m3
cp_pwm = 1990;             %J/kg*K

%SECONDARY WICK -- nickel
alpha2 = 0.5;
kmsw = 0.4186;             %W/m*K
r_por_sw = 2e-5;           %m
rho_sw = 930;              %kg/m3
cp_swm = 1990;             %J/kg*K

%COMPENSATION CHAMBER -- stainless steel
rho_a = 7740;							 %kg/m3
cp_a = 510;                %J/kg*K

%BAYONET -- copper
kmb = 401;                 %W/m*K
rho_bay = 8940;            %kg/m3
cp_bay = 390;              %J/kg*K

%EVPORATOR WALL -- fortal
kwall = 132;               %W/m*K
rho_we = 2810;             %kg/m3
cp_wall = 0.7*910;         %J/kg*K

%COMPENSATION CHAMBER
ra = 0.05;                 %m
La = 0.23;                 %m 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%% START UP %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[u_v,u_l,v_v,v_l] = propisocor(Pi);

v_sp = v_v*fr+(1-fr)*v_l;      %specific volume - will remain constant since the LHP is a closed device
u1 = u_v*fr+(1-fr)*u_l;        %specific energy at the starting point

[kl,mu_l,cp_l,kv,sigma,mu_v,rho_v,h_sv,h_sl,rho_l,cp_v] = phy_prop_water(T_amb);

%masses (material plus liquid in it)
m_vo = nvg*rvg^2*Lvg*rho_v;
m_wall = pi*((rpw+thickev)^2-rpw^2)*Lpw*rho_we;
m_pw = pi*(rpw^2-rsw^2)*Lpw*rho_pw*(1-alpha1)+pi*(rpw^2-rsw^2)*Lpw*rho_l*alpha1;
m_sw = pi*(rsw^2-rbe^2)*Lsw*rho_sw*(1-alpha2)+pi*(rsw^2-rbe^2)*Lsw*rho_l*alpha2;
m_bay = pi*(rbe^2-rbi^2)*Lbay*rho_bay+pi*(rbi^2)*Lbay*rho_l;
m_evap = m_vo+m_pw+m_wall+m_sw+m_bay;
%specific heats - considering liquid and material
cp_pw = (cp_pwm*pi*(rpw^2-rsw^2)*Lpw*rho_pw*(1-alpha1) + pi*(rpw^2-rsw^2)*Lpw*alpha1*rho_l*cp_l)/(m_pw);
cp_sw = (cp_swm*pi*(rsw^2-rbe^2)*Lpw*rho_sw*(1-alpha2) + pi*(rsw^2-rbe^2)*Lsw*alpha2*rho_l*cp_l)/(m_sw);
cp_av = (m_vo*cp_v+m_wall*cp_wall+cp_pw*m_pw+cp_sw*m_sw+pi*(rbe^2-rbi^2)*Lbay*rho_bay*cp_bay+pi*(rbi^2)*Lbay*rho_l*cp_l)/(m_evap);

%at the beginning there is the only the heat Qext
Qdot = Qext;

%internal energy balance at the evaporator
u2 = u1 + (Qdot*h_step)/m_evap;

%now I have to find the new P1 that gives me u2
newP1 = Pi;
toll = 0;

while toll < 1

newP1 = newP1*1.0001;
[u_v,u_l,v_v,v_l] = propisocor(newP1);
xi = (v_sp-v_l)/(v_v-v_l);
u = xi*u_v+(1-xi)*u_l;
toll = u/u2;

end

%now this is the new starting pressure
P1 = newP1;

%calcuate temeprature of vaporization
Tevap = 375.9812140037*((P1*10^-5)^0.0679928133);

%computing TOTAL MASS - liquid density is at starting temperature - conservative assumption
m_cc = pi*((ra+thickev)^2-ra^2)*La*rho_a+0.5*pi*ra^2*La*rho_l;
m_vl = pi*(re_vl^2-ri_vl^2)*L_vl*(rho_mvl+rho_v);
m_ll = pi*(re_ll^2-ri_ll^2)*L_ll*(rho_mll+rho_l);
m_cond = pi*(re_cond^2-ri_cond^2)*L_cond*(rho_mcond+rho_l);

mtot_LHP = m_evap+m_cc+m_vl+m_ll+m_cond;

V_pw = pi*(rpw^2-rsw^2)*Lpw*(1-alpha1);
V_sw = pi*(rsw^2-rbe^2)*Lsw*(1-alpha2);

%STARTING MASS FLOW RATE MASS FLOW RATE CALCULATION
heat_vap = 1000*(-0.00000003810305800652*Tevap^4 + 0.00004131281274891150*Tevap^3 - 0.01765533525387720000*Tevap^2 + 1.19284958188491000000*Tevap + 2861.70706550623000000000);     %J/kg
mdot = (Qext)/(heat_vap);				%kg/s 

%number of nodes of the condenser
n_c = round((rho_l*pi*ri_cond^2*L_cond)/(mdot*h_step));

%creating vector of correct dimensions with boundary conditions
[vT_cc,vT_pw,vT_wall,vT_vo,vP2,vP3,vPpw,vP_cc,vPvo,vP_vl,vT_vl,vP_cond,vT_cond,vQc,vx,vT_ll,vP_ll,vQamb,vP1,vT1,vT_LHP,vP_LHP,vmdot,vQext,vQris,vR_tot_LHP,vQdot] = v_zero(tmax,nb_vl,n_c,nb_ll);

%saving first values in first line (t0)
vT1(1,2) = Tevap;
vT_vo(1,2) = Tevap;
vT_cc(1,2) = Tevap;
vT_pw(1,2) = Tevap;
vT_wall(1,2) = Tevap;

vP1(1,2) = P1;
vP2(1,2) = P1;
vP3(1,2) = P1;
vPpw(1,2) = P1;
vP_cc(1,2) = P1;
vPvo(1,2) = P1;

vmdot(1,2) = mdot;

vu2 = zeros(tmax,2);
vQsolid = zeros(tmax,2);
vhci = zeros(tmax,n_c+1);

for i = 1:tmax
vhci(i,1)=i;
end

%creating external heat variation vector
vQext(1:1100,2) = Qext;
for i = 1:40
vQext(1100+i,2) = Qext+5*i;
end
vQext(1141:1700,2) = Qext+5*40;
for i = 1:40
vQext(1700+i,2) = Qext+5*40-5*i;
end
vQext(1741:end,2) = Qext;

P2 = P1;
T1 = T_amb;

for t = 2:h_step:tmax

disp(t);
fflush(stdout);

Qext = vQext(t,2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%   EVAPORATOR   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[kl,mu_l,cp_l,kv,sigma,mu_v,rho_v,h_sv,h_sl,rho_l,cp_v] = phy_prop_water(T1);

%pressure drop bayonet
Rd12 = (8*mu_l*La)/(rho_l*pi*(ra^4));
P2 = P1 - mdot*Rd12;

Rd23 = (8*mu_l*(Lbay))/(rho_l*pi*(rbi^4));
P3 = P2 - mdot*Rd23;

deltaPbay = mdot*(Rd12+Rd23);

if floor(t) == t
vP2(t,2) = P2;
vP3(t,2) = P3;
end

if t == 2
%effect of capillarity in the two wicks
[kl,mu_l,cp_l,kv,sigma,mu_v,rho_v,h_sv,h_sl,rho_l,cp_v] = phy_prop_water(T1);
Pcapsw = (2*sigma)/r_por_sw;
Pcappw = (2*sigma)/r_por_pw;
Ppw=P3;
else
%effect of capillarity in the two wicks
[kl,mu_l,cp_l,kv,sigma,mu_v,rho_v,h_sv,h_sl,rho_l,cp_v] = phy_prop_water(T_pw);
Pcapsw = (2*sigma)/r_por_sw;
Pcappw = (2*sigma)/r_por_pw;
if deltaP > (Pcappw+Pcapsw)
disp('deltaP>capillary pump');
deltaP = (Pcappw+Pcapsw);
end
Ppw = P3 + deltaP;
end

%pressure drop in the vapour grooves
Rdvg = (8*mu_l*Lvg)/(rho_l*pi*(rvg^4));
deltaPvo = (mdot/nvg)*Rdvg;
Pvo = Ppw -(mdot/nvg)*Rdvg;

if floor(t) == t
vPpw(t,2) = Ppw;
vPvo((t),2) = Pvo;
end

%quantities to feed the ODE system
cp_cc = (0.6*pi*(ra^2)*La*rho_l*cp_l+m_cc*cp_a)/(m_cc);
cp_pw = (cp_pwm*pi*(rpw^2-rsw^2)*Lpw*rho_pw*(1-alpha1) + pi*(rpw^2-rsw^2)*Lpw*alpha1*rho_l*cp_l)/(m_pw);

%resistance between primary wick and vapour grooves
hcvg = 3.66*(kv/(2*rvg));
kpw = alpha1*kmpw+(1-alpha1)*kl;
Avg = nvg*rvg*Lvg;                                   %considering a rectangular exchange surface
R_pwvo = 1/(hcvg*Avg)+(log(rpw/rsw))/(2*pi*kpw*Lpw);

%resistance between the vapour grooves and the evaporator wall
R_vowall = 1/(hcvg*Avg)+(log((rpw+thickev)/rpw))/(2*pi*kwall*Lpw);

%resistance between the evaporator wall and the primary wick
R_wallpw = (((log(rpw/rsw))/(2*pi*kpw*Lpw))*(1/(hcvg*Avg)))/(1/(hcvg*Avg)+(log(rpw/rsw))/(2*pi*kpw*Lpw))+(log((rpw+thickev)/rpw))/(2*pi*kwall*Lpw);

%resistance between the primary wick and the liquid inside the bayonet
ksw = alpha2*kmsw+(1-alpha2)*kl;
hcbay = 3.66*(kl/(2*rbi));
Abay = 2*pi*rbi*Lbay;
Rpw2 = (log(rpw/rsw))/(2*pi*kpw*Lpw)+(log(rsw/rbe))/(2*pi*ksw*Lsw)+1/(hcbay*Abay);

%saturation temperature before the primary wick
Tsat = 375.9812140037*((P3*10^-5)^0.0679928133);

hLV = 1000*(-0.00000003810305800652*Tsat^4 + 0.00004131281274891150*Tsat^3 - 0.01765533525387720000*Tsat^2 + 1.19284958188491000000*Tsat + 2861.70706550623000000000);

%SOLVING ODE SYSTEM EVAPORATOR
tempo_evap = (1:0.1:2);

Tstartcc = Tsat;

y_cc = lsode("f_cc",Tstartcc,tempo_evap);

T_cc = y_cc(end);

x0 = [Tsat;Tsat;Tsat];

y_evap = lsode("odeevaporator2",x0,tempo_evap);

T_vo = y_evap(end,1);
T_pw = y_evap(end,2);
T_wall = y_evap(end,3);

%due to two-phase condition, this is the pressure of the compensation chamber
P_cc = 10^5*(0.00000001427245898185*T_cc^4 - 0.00001713237691886840*T_cc^3 + 0.00778985619620290000*T_cc^2 - 1.58733653961135000000*T_cc + 122.10792804363100000000);

if floor(t) == t
vT_cc(t,2) = T_cc;
vT_vo(t,2) = T_vo;
vT_pw(t,2) = T_pw;
vT_wall(t,2) = T_wall;
vP_cc(t,2) = P_cc;
end

%create vector collecting evaporator temperatures
vT_evaporator = [T1,T_cc,T_pw,T_wall,T_vo];
vP_evaporator = [P2,P3,P_cc,Ppw,Pvo];

if floor(t) == t
vT_LHP(t,2:6) = vT_evaporator;
vP_LHP(t,2:6) = vP_evaporator;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% VAPOUR LINE  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%initial values from the evaporator
P_vg = Pvo;                %bar
T_vg = T_vo;               %K
[kl,mu_l,cp_l,kv,sigma,mu_v,rho_v,h_sv,h_sl,rho_l,cp_v] = phy_prop_water(T_vg);
rho_vg = rho_v;            %kg/m3
v_vg = mdot/(nvg*rho_vg*pi*rvg^2);   %m/s

%calculates properties at the vapor chamber
Rc_vc =(0.5*v_vg)/(2*pi*nvg*(rvg^2));
P_vc = P_vg - mdot*Rc_vc;
T_vc = T_vg*(P_vg/P_vc)^((1-k_g)/k_g);
rho_vc = rho_vg*(P_vc/P_vg)^(1/k_g);
v_vc = mdot/(rho_vc*pi*r_vc^2);

%calculates properties at the inlet of vapor line
Rc_vli = (k_in3*v_vc)/(2*pi*(r_vc^2));
P_vli = P_vc - mdot*Rc_vli;
T_vli = T_vc*(P_vc/P_vli)^((1-k_g)/k_g);
rho_vl = rho_vc*(P_vli/P_vc)^(1/k_g);
v_vl = mdot/(rho_vl*pi*ri_vl^2);

%initialize cycle variables
P_vl = P_vli;
T_vl = T_vli;

deltaPvl = mdot*(Rc_vc+Rc_vli);

%cicle to calculate properties values in vapor line -- general
for k= 1:(nb_vl*2)

%save the new variable coming from the previous cycle
if floor(t) == t
vP_vl(t,(k+1)) = P_vl;
vT_vl(t,(k+1)) = T_vl;
end

if mod(k,2) < 0 && mod(k,2) > 0
    Rc_turn_vl = (k_90*v_vl)/(2*pi*(ri_vl^2));
else                                            
    Rc_turn_vl = 0;                                     %for the concentrate loss, I consider the turns, so every odd index
end

[kl,mu_l,cp_l,kv,sigma,mu_v,rho_v,h_sv,h_sl,rho_l,cp_v] = phy_prop_water(T_vl);
Rd_vl =(8*mu_v*Lx_vl)/(rho_vl*pi*(ri_vl^2));
Rt_vl = Rd_vl+Rc_turn_vl;

T_vl = T_vl*(1-(mdot*Rt_vl)/P_vl)^((1-k_g)/k_g);
rho_vl = rho_vl*(1-(mdot*Rt_vl)/P_vl)^(1/k_g);
P_vl = P_vl - mdot*Rt_vl+(g*rho_vl*deltaz_vl);
v_vl = mdot/(rho_vl*pi*(ri_vl^2));

deltaPvl = mdot*Rt_vl-(g*rho_vl*deltaz_vl)+deltaPvl;

end

if floor(t) == t
vT_LHP(t,7:(6+nb_vl*2)) = vT_vl(t,2:end);
vP_LHP(t,7:(6+nb_vl*2)) = vP_vl(t,2:end);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  CONDENSER %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%first node of the condenser
P_c = P_vl;
T_c = T_vl;
x = 1;
sumQc = 0;
deltaPcond = 0;

for k = 1:n_c

[kl,mu_l,cp_l,kv,sigma,mu_v,rho_v,h_sv,h_sl,rho_l,cp_v] = phy_prop_water(T_c);

%two-phase parameters
rho_2p = x*rho_v+rho_l*(1-x);               %kg/m3
mu_2p = mu_l-2.5*mu_l*((x*rho_l)/(x*rho_l+(1-x)*rho_v))^2+((x*rho_l*(1.5*mu_l+mu_v))/(x*rho_l+(1-x)*rho_v)); %Pa*s

%cycle for viscosity
if k < 2
    mu_c = mu_v;
else
    mu_c = mu_2p;
end

%cycle for density
if k < 2
   rho_c = rho_v;
else
   rho_c = rho_2p;
end

%cycle for Lx_cond
if k == 1 
	Lx_cond = 0.01;
else 
  Lx_cond = L_cond/n_c;
end

v_c = mdot/(rho_c*pi*ri_cond^2);  

%Pressure Resistances
Rd_cond = (8*mu_c*Lx_cond)/(rho_c*pi*(ri_cond^4));

if k == 1
    Rc_cond = (0.19*v_c)/(2*pi*(ri_cond)^2); %0.19 is because we considered a 90 degrees turn with a radius of 1.5time the diameter
		else                                            
    Rc_cond = 0; 
end

%pressure calculation
P_c = P_c - mdot*(Rc_cond+Rd_cond);

%temperature calculation
T_c0 = T_c;

%exchanbge surfaces
Ae_cond= 2*pi*re_cond*Lx_cond;       %m2
Ai_cond= 2*pi*ri_cond*Lx_cond;       %m2

Re = (2*mdot*(1-x))/(pi*mu_c*ri_cond);
Pr = (mu_c*cp_l)/kl;
P_star = P_c/P_crit;
af = 0.023*(Re^0.8)*(Pr^0.3)*(kl/(2*ri_cond)) ;     %W/m2*K

%cycle for boundary condition and htc
hce = hc;

%SHAH CORRELATION for two phase fluid	 
sh = af*((1-x)^0.8+((3.8*x^0.76*(1-x)^0.04)/(P_star^0.38)));
%vapour convective heat transfer coefficient
hc_v = 3.66*(kv/(2*ri_cond));

%defining convective heat tranfer coefficient inside the pipe
if hc_v > sh
    hci = hc_v;
elseif sh>250
    hci=250;
else	
    hci = sh;
end

if floor(t) == t
vhci(t,k+1) = hci;
end

if t > 4
%smoothing of hci
hci = ((vhci((t-1),(k+1))+vhci((t-2),(k+1))+vhci((t-3),(k+1)))/3);
end

%FOR THE ODE
mcond1 = pi*ri_cond^2*Lx_cond*rho_c;
mcond2 = pi*(re_cond^2-ri_cond^2)*Lx_cond*rho_mcond;
mcond = mcond1+mcond2;

hLV_cond = 1000*(-0.00000003810305800652*T_c^4 + 0.00004131281274891150*T_c^3 - 0.01765533525387720000*T_c^2 + 1.19284958188491000000*T_c + 2861.70706550623000000000);
x0 = x;

tempo_cond = (1:0.1:2);

if T_hs < T_c
if x < 0.02
x = 0;
hci = af;
mu_c = mu_l;
rho_c = rho_l;
Rt_cond = 1/(hci*Ai_cond)+(log(re_cond/ri_cond))/(2*pi*kn_cond*Lx_cond)+1/(hce*Ae_cond);
T_c = T_c + (Q_c/mdot)/cp_l;
else
Rt_cond = 1/(hci*Ai_cond)+(log(re_cond/ri_cond))/(2*pi*kn_cond*Lx_cond)+1/(hce*Ae_cond);
y_cond = lsode('f_cond',x0,tempo_cond);
x = y_cond(end);
T_c = 375.9812140037*((P_c*10^-5)^0.0679928133);
end
else
hci = 3.66*(kv/(2*ri_cond));
Rt_cond = 1/(hci*Ai_cond)+(log(re_cond/ri_cond))/(2*pi*kn_cond*Lx_cond)+1/(hce*Ae_cond);
Q_c = (T_hs-T_c)/Rt_cond;
T_c = T_c + (Q_c/mdot)/cp_l;
x = 1;
end

%heat lost at the node
Q_c = (T_hs-T_c)/Rt_cond;
sumQc = sumQc+Q_c;

deltaPcond = deltaPcond+mdot*(Rc_cond+Rd_cond);

if floor(t)==t
vQc(t,k+1) = Q_c;
vT_cond(t,k+1) = T_c;
vP_cond(t,k+1) = P_c;
vx(t,k+1) = x;
end

end

if floor(t)== t
vT_LHP(t,(7+(nb_vl*2)):((6+(nb_vl*2))+5)) = vT_cond(t,2:6);
vP_LHP(t,(7+(nb_vl*2)):((6+(nb_vl*2))+5)) = vP_cond(t,2:6);
vT_LHP(t,(6+(nb_vl*2)+6):((5+(nb_vl*2))+11)) = vT_cond(t,end-4:end);
vP_LHP(t,(6+(nb_vl*2)+6):((5+(nb_vl*2))+11)) = vP_cond(t,end-4:end);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% LIQUID LINE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%initial values from the condenser
T_ll = T_c;           %K
P_ll = P_c;           %bar
rho_ll = rho_l;			%kg/m3
[kl,mu_l,cp_l,kv,sigma,mu_v,rho_v,h_sv,h_sl,rho_l,cp_v] = phy_prop_water(T_ll);
h_ll = h_sl;
sumQ_amb = 0;
deltaPll = 0;

%liquid line cycle
for k= 1:(nb_ll*2)

%values for hci    
[kl,mu_l,cp_l,kv,sigma,mu_v,rho_v,h_sv,h_sl,rho_l] = phy_prop_water(T_ll);
Re = 2*mdot/(pi*mu_l*ri_ll);
Pr = (mu_l*cp_l)/kl;

if T_ll < T_amb
    n_dittus = 0.3;
else
    n_dittus = 0.4;
end

hci_ll = 0.023*(Re^0.8)*(Pr^n_dittus)*(kl/(2*ri_ll));

%thermal resistance
Rt_ll = (1/(hce_ll*2*pi*re_ll*Lx_ll))+(1/(hci_ll*2*pi*ri_ll*Lx_ll));               %W/m2*K

%heat exchanged with surroundings    
Q_amb = -(T_ll-T_amb)/(Rt_ll);
sumQ_amb = sumQ_amb+Q_amb;
if floor(t)==t
vQamb(t,(k+1)) = Q_amb;
end

%pressure resistances
Rd_ll = (8*mu_l*Lx_ll)/(rho_l*pi*(ri_ll^4));

v_ll = mdot/(rho_l*pi*ri_ll^2);

if mod(k,2) < 0 && mod(k,2) > 0
    Rc_ll = (k_90*v_ll)/(2*pi*(ri_ll^2));
else                                            
    Rc_ll = 0;                                     %for the concentrate loss, I consider the turns, so every odd index
end

Rp_ll = Rc_ll + Rd_ll;

%pressure, entalphy and temperature calculation
P_ll = P_ll-mdot/Rp_ll-(g*rho_ll*deltaz_ll);
h_ll = h_ll +Q_amb/mdot;
T_ll = T_ll +Q_amb/(mdot*cp_l);

deltaPll = deltaPll+mdot/Rp_ll+(g*rho_ll*deltaz_ll);

%update pressure, temperature 
if floor(t) == t
vP_ll(t,(k+1)) = P_ll;
vT_ll(t,(k+1)) = T_ll;
end

end

if floor(t)== t
vT_LHP(t,(6+2*nb_vl+11):((5+2*nb_vl+11+2*nb_ll))) = vT_ll(t,2:end);
vP_LHP(t,(6+2*nb_vl+11):((5+2*nb_vl+11+2*nb_ll))) = vP_ll(t,2:end);
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%closing cycle
T1 = T_ll;
P1 = P_ll;

%calculation of new mass flow rate
heat_vap = 1000*(-0.00000003810305800652*T_vo^4 + 0.00004131281274891150*T_vo^3 - 0.01765533525387720000*T_vo^2 + 1.19284958188491000000*T_vo + 2861.70706550623000000000);      %J/kg
mdot = Qext/heat_vap;				%kg/s

%deltaPtotcalculation
deltaP = deltaPll + deltaPcond + deltaPvl + deltaPbay + deltaPvo;

%increasing the pressure in the evaporator due to the isochoric heating - repeating the start up loop
%parameters for the calculation of the new u2
if t < 5
deltaT_av = 0;
else
deltaT_av = ((m_wall*vT_wall(t,2)+m_pw*vT_pw(t,2))-(m_wall*vT_wall(t-1,2)+m_pw*vT_pw(t-1,2)))/(m_wall+m_pw);    %weighted average temperature difference between the two massive part of the evaporator  
end

%ISOCHORIC HEATING
T_av = (m_wall*vT_wall(t,2)+m_pw*vT_pw(t,2))/(m_wall+m_pw);
[kl,mu_l,cp_l,kv,sigma,mu_v,rho_v,h_sv,h_sl,rho_l,cp_v] = phy_prop_water(T_av);
cp_av = (m_vo*cp_v+m_wall*cp_wall+cp_pw*m_pw+cp_sw*m_sw+pi*(rbe^2-rbi^2)*Lbay*rho_bay*cp_bay+pi*(rbi^2)*Lbay*rho_l*cp_l)/(m_evap);
Qsolid = (m_wall+m_pw)*cp_av*(deltaT_av/h_step);
Qdot = Qext+sumQc+sumQ_amb-Qsolid;

[u_v,u_l,v_v,v_l] = propisocor(P1);
u2 = u_l+(Qdot*h_step)/m_evap;

if floor(t) == t
vu2(t,2) = u2;
vQsolid(t,2) = Qsolid;
end

gamma = (u_l-u2)/u2;

while abs(gamma) > 0.000001
newP1 = newP1*(1-gamma);
[u_v,u_l,v_v,v_l] = propisocor(newP1);
u = u_l;
gamma = ((u-u2)/u2);
end

Qris = Qext+sumQc+sumQ_amb;

dPisocor = newP1-P1;
P1 = newP1;
R_tot_LHP = (T_wall-T_ll)/Qext;

if floor(t) == t
vQris(t,2) = Qris;
vQdot(t,2) = Qdot;
vP1(t,2) = P1;
vT1(t,2) = T1;
vmdot(t,2) = mdot;
vR_tot_LHP(t,2) = R_tot_LHP;
end

%istantly plotting the wall temperature point by point in order to see if something is wrong and eventually stop the simulation
plot(vT_wall(1:t,2)-273.15,'b')

%ending big for cycle
end

figure
plot(vT_cond(2:end,2)-273.15,'g')
hold on
plot(vT_cond(2:end,end)-273.15,'p')
plot(vT_pw(2:end,2)-273.15,'b')
plot(vT_vo(2:end,2)-273.15,'c')
plot(vT_cc(2:end,2)-273.15,'r')
plot(vT_wall(2:end,2)-273.15,'y')

toc